Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1933)

Unified Diff: components/safe_browsing/csd.proto

Issue 2777853005: Generalize the usage of referrer chain (Closed)
Patch Set: address lpz's comments Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/safe_browsing/safe_browsing_service.h ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: components/safe_browsing/csd.proto
diff --git a/components/safe_browsing/csd.proto b/components/safe_browsing/csd.proto
index eb2d75e932b54bd998d0f4449013e94fdd3b3955..fc58f5d950060c1ec8f72e7bfcd50ff499759eb4 100644
--- a/components/safe_browsing/csd.proto
+++ b/components/safe_browsing/csd.proto
@@ -506,10 +506,23 @@ message ClientDownloadRequest {
message ReferrerChainEntry {
enum URLType {
- DOWNLOAD_URL = 1;
+ // URL of safe browsing events that are at the end of the referrer chain.
+ // e.g. URL of a download, URL of a low reputation login page, etc.
+ EVENT_URL = 1; // e.g.
+
+ // Landing page is the page user directly interacts with to trigger the
+ // above event, e.g. the page where user clicks a download button.
LANDING_PAGE = 2;
+
+ // Landing referrer is the one user directly interacts with right before
+ // navigating to the landing page.
LANDING_REFERRER = 3;
+
+ // Client redirect refers to committed navigation between landing page and
+ // the targeted event, or between landing referrer page and landing page.
+ // Client redirect is not triggered by user gesture.
CLIENT_REDIRECT = 4;
+
DEPRECATED_SERVER_REDIRECT = 5; // Deprecated
}
@@ -526,7 +539,7 @@ message ReferrerChainEntry {
// Only set if it is different from |url|.
optional string main_frame_url = 9;
// Type of URLs, such as download url, download referrer, etc.
optional URLType type = 2 [default = CLIENT_REDIRECT];
// IP addresses corresponding to this host.
« no previous file with comments | « chrome/browser/safe_browsing/safe_browsing_service.h ('k') | no next file » | no next file with comments »
@@ -526,7 +539,7 @@ message ReferrerChainEntry {
// Only set if it is different from |url|.
optional string main_frame_url = 9;
- // Type of URLs, such as download url, download referrer, etc.
+ // Type of URLs, such as event url, landing page, etc.
optional URLType type = 2 [default = CLIENT_REDIRECT];
// IP addresses corresponding to this host.

Powered by Google App Engine
This is Rietveld 408576698